@@ -1,13 +1,3 @@
-################################################################################
-#
-# File      : Daemon.pm
-# Author    : D.A.Dokter
-# Created   : Mon Nov 11 17:43:16 2002
-# Version   : $Id: Daemon.pm,v 1.13 2015/01/29 15:30:11 wyldebeast Exp $
-# Copyright : Wyldebeast & Wunderliebe
-#
-################################################################################
-
 package Net::HL7::Daemon;
 
 use IO::Socket qw(AF_INET INADDR_ANY inet_ntoa);
@@ -46,6 +36,7 @@ for the IO::Socket::INET. Default settings are: Listen = SOMAXCONN,
 Proto = tcp, Reuse = 1.
 
 =cut
+
 sub new
 {
     my($class, %args) = @_;
@@ -69,6 +60,7 @@ is returned containing the new I<Net::HL7::Daemon::Client> reference
 and the peer address; the list will be empty upon failure.
 
 =cut
+
 sub accept
 {
     my $self = shift;
@@ -89,6 +81,7 @@ sub accept
 Returns the host where this daemon can be reached.
 
 =cut
+
 sub getHost
 {
     my $self = shift;
@@ -112,6 +105,7 @@ Returns the port on which this daemon is listening.
 =back
 
 =cut
+
 sub getPort {
 
     my $self = shift;
@@ -147,6 +141,23 @@ of I<Net::HL7::Daemon>.
 
 =over 4
 
+=item B<$d = new Net::HL7::Daemon::Client()>
+
+Create a new instance of the Client class. Arguments are the same as
+for the IO::Socket::INET. Normally, you shouldn't do this...
+
+=cut
+
+sub new
+{
+    my($class, %args) = @_;
+    $args{Timeout} ||= 10;
+
+    return $class->SUPER::new(%args);
+}
+
+=pod
+
 =item B<getRequest()>
 
 Get the current request on this client. The current request is either
@@ -163,13 +174,6 @@ message. So discard the client only when there's no more requests
 pending, or the delivering service might experience timeouts.
 
 =cut
-sub new
-{
-    my($class, %args) = @_;
-    $args{Timeout} ||= 10;
-
-    return $class->SUPER::new(%args);
-}
 
 sub getRequest
 {
@@ -232,7 +236,7 @@ sub getNextRequest
 
 =pod
 
-=item B<sendAck([$res])>
+=item B<sendAck($res)>
 
 Write a I<Net::HL7::Messages::ACK> message to the client as a
 response, to signal success. You may provide your own
@@ -240,49 +244,51 @@ Net::HL7::Response, but it is better to rely on the ACK that is
 generated internally.
 
 =cut
+
 sub sendAck {
 
     my ($self, $res) = @_;
 
     # If this is true, we didn't get the incoming message yet!
     if (! ${*$self}{'REQ'}) {
-	$self->getRequest() || return undef;
+        $self->getRequest() || return undef;
     }
 
     if (! ref $res) {
-	$res = new Net::HL7::Messages::ACK(${*$self}{'REQ'});
+        $res = new Net::HL7::Messages::ACK(${*$self}{'REQ'});
     }
 
     print $self $Net::HL7::Connection::MESSAGE_PREFIX . $res->toString() .
-	$Net::HL7::Connection::MESSAGE_SUFFIX;
+        $Net::HL7::Connection::MESSAGE_SUFFIX;
 }
 
 =pod
 
-=item B<sendNack([$errMsg], [$res])>
+=item B<sendNack($errMsg, $res)>
 
 Write a I<Net::HL7::Messages::ACK> message to the client as a
 response, with the Acknowledge Code (MSA(1)) set to CE or AE,
 depending on the original request, to signal an error.
 
 =cut
+
 sub sendNack {
 
     my ($self, $errMsg, $res) = @_;
 
     # If this is true, we didn't get the incoming message yet!
     if (! ${*$self}{'REQ'}) {
-	$self->getRequest() || return undef;
+        $self->getRequest() || return undef;
     }
-
+    
     if (! ref $res) {
-	$res = new Net::HL7::Messages::ACK(${*$self}{'REQ'});
+        $res = new Net::HL7::Messages::ACK(${*$self}{'REQ'});
     }
-
+    
     $res->setAckCode("E", $errMsg);
-
+    
     print $self $Net::HL7::Connection::MESSAGE_PREFIX . $res->toString() .
-	$Net::HL7::Connection::MESSAGE_SUFFIX;
+        $Net::HL7::Connection::MESSAGE_SUFFIX;
 }
 
 =pod
@@ -295,16 +301,17 @@ can hold an arbitrary HL7 message.
 =back
 
 =cut
+
 sub sendResponse {
 
     my ($self, $res) = @_;
 
     print $self $Net::HL7::Connection::MESSAGE_PREFIX . $res->toString() .
-	$Net::HL7::Connection::MESSAGE_SUFFIX;
+        $Net::HL7::Connection::MESSAGE_SUFFIX;
 }
 
-
 =pod
+
 =head1 SEE ALSO
 
 RFC 2068
